Index: /trunk/src/org/openstreetmap/josm/gui/layer/geoimage/GeoImageLayer.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/gui/layer/geoimage/GeoImageLayer.java	(revision 7763)
+++ /trunk/src/org/openstreetmap/josm/gui/layer/geoimage/GeoImageLayer.java	(revision 7764)
@@ -41,4 +41,5 @@
 
 import org.openstreetmap.josm.Main;
+import org.openstreetmap.josm.actions.LassoModeAction;
 import org.openstreetmap.josm.actions.RenameLayerAction;
 import org.openstreetmap.josm.actions.mapmode.MapMode;
@@ -838,5 +839,5 @@
     /**
      * Determines if the functionality of this layer is available in
      * the specified map mode.  SelectAction is supported by default,
      * other map modes can be registered.
      * @param mapMode Map mode to be checked
@@ -845,5 +846,7 @@
      */
     private static final boolean isSupportedMapMode(MapMode mapMode) {
-        if (mapMode instanceof SelectAction) return true;
+        if (mapMode instanceof SelectAction || mapMode instanceof LassoModeAction) {
+            return true;
+        }
         if (supportedMapModes != null) {
             for (MapMode supmmode: supportedMapModes) {
@@ -838,5 +839,5 @@
     /**
      * Determines if the functionality of this layer is available in
-     * the specified map mode.  SelectAction is supported by default,
+     * the specified map mode. {@link SelectAction} and {@link LassoModeAction} are supported by default,
      * other map modes can be registered.
      * @param mapMode Map mode to be checked
